@@ -84,6 +84,7 @@ class NVD3Chart:
         * ``charttooltip`` - Custom tooltip string
         * ``header_css`` - False / True
         * ``header_js`` - Custom tooltip string
+        * ``color_category`` - Defien color category (eg. category10, category20, category20c)
     """
     count = 0
     dateformat = '%x'
@@ -107,11 +108,12 @@ class NVD3Chart:
     date_flag = False
     charttooltip = ''
     tooltip_condition_string = ''
+    color_category = '' # category10, category20, category20c
 
     header_css = ['http://nvd3.org/src/nv.d3.css']
     header_js = ['http://nvd3.org/lib/d3.v2.js', 'http://nvd3.org/nv.d3.js']
 
-    def __init__(self, name=None, **kwargs):
+    def __init__(self, name=None, color_category=None, **kwargs):
         """
         Constructor
         """
@@ -122,12 +124,16 @@ class NVD3Chart:
         self.series = []
         self.axislist = {}
         self.template_page_nvd3 = Template(template_page_nvd3)
+        self.color_category = 'category10'
 
         if not name:
             self.count += 1
             name = "chart%d" % (self.count)
         self.name = name
 
+        if color_category:
+            self.color_category = color_category
+
         if 'stacked' in kwargs and kwargs["stacked"]:
             self.stacked = True
 
@@ -172,6 +178,9 @@ class NVD3Chart:
         if 'disabled' in kwargs and kwargs["disabled"]:
             data_keyvalue["disabled"] = 'true'
 
+        if 'color' in kwargs and kwargs["color"]:
+            data_keyvalue["color"] = kwargs["color"]
+
         if extra.get('tooltip'):
             self.custom_tooltip_flag = True
 
@@ -202,8 +211,6 @@ class NVD3Chart:
                 self.tooltip_condition_string += \
                     "var y = " + _start + " String(e.point.y) " + _end + ";\n"
 
-        #print self.tooltip_condition_string
-        #print "----------------------------"
         self.series.append(data_keyvalue)
 
     def set_graph_height(self, height):
@@ -310,6 +317,10 @@ class NVD3Chart:
             stab() + 'nv.addGraph(function() {\n'
 
         self.jschart += stab(2) + 'var chart = nv.models.%s();\n' % self.model
+
+        if self.color_category:
+            self.jschart += stab(2) + 'chart.color(d3.scale.%s().range());\n' % self.color_category
+
         if self.stacked:
             self.jschart += stab(2) + "chart.stacked(true);"
 
