@@ -12,11 +12,16 @@ class linePlusBarChart(NVD3Chart):
 
         from nvd3 import linePlusBarChart
         chart = linePlusBarChart(name='linePlusBarChart', date=True)
+
         xdata = [1365026400000000, 1365026500000000, 1365026600000000]
         ydata = [-6, 5, -1]
         y2data = [36, 55, 11]
-        chart.add_serie(y=ydata, x=xdata)
-        chart.add_serie(y=y2data, x=xdata)
+
+        extra_serie = {"tooltip": {"y_start": "There is ", "y_end": " calls"}}
+        chart.add_serie(name="Serie 1", y=ydata, x=xdata, extra=extra_serie)
+
+        extra_serie = {"tooltip": {"y_start": "There is ", "y_end": " min"}}
+        chart.add_serie(name="Serie 2", y=y2data, x=xdata, extra=extra_serie)
         chart.buildhtml()
 
     Javascript generated::
@@ -62,7 +67,18 @@ class linePlusBarChart(NVD3Chart):
                 .tickFormat(d3.format(',f'));
             chart.y2Axis
                 .tickFormat(function(d) { return '$' + d3.format(',f')(d) });
-
+            chart.tooltipContent(function(key, y, e, graph) {
+                var x = d3.time.format('%d %b %Y')(new Date(parseInt(graph.point.x)));
+                var y = String(graph.point.y);
+                if(key.indexOf('Serie 1') > -1 ){
+                    var y = '$ ' +  String(graph.point.y) ;
+                }
+                if(key.indexOf('Serie 2') > -1 ){
+                    var y =  String(graph.point.y)  + ' min';
+                }
+                tooltip_str = '<center><b>'+key+'</b></center>' + y + ' on ' + x;
+                return tooltip_str;
+            });
             d3.select('#linePlusBarChart svg')
                 .datum(data_linePlusBarChart)
                 .transition().duration(500)
@@ -74,6 +90,7 @@ class linePlusBarChart(NVD3Chart):
     def __init__(self, height=450, width=None, date=False, **kwargs):
         NVD3Chart.__init__(self, **kwargs)
         if date:
+            self.set_date_flag(True)
             self.create_x_axis('xAxis', format='%d %b %Y', date=True)
             self.set_custom_tooltip_flag(True)
         else:
