@@ -13,7 +13,9 @@ class lineWithFocusChart(NVD3Chart):
         chart = lineWithFocusChart(name='lineWithFocusChart', date=True)
         xdata = [1365026400000000, 1365026500000000, 1365026600000000]
         ydata = [-6, 5, -1]
-        chart.add_serie(y=ydata, x=xdata)
+
+        extra_serie = {"tooltip": {"y_start": "", "y_end": " ext"}}
+        chart.add_serie(name="Serie 1", y=ydata, x=xdata, extra=extra_serie)
         chart.buildhtml()
 
     Javascript generated::
@@ -36,13 +38,22 @@ class lineWithFocusChart(NVD3Chart):
         nv.addGraph(function() {
                 var chart = nv.models.lineWithFocusChart();
                 chart.yAxis
-                    .tickFormat(d3.format(',.2f'))
+                    .tickFormat(d3.format(',.2f'));
                 chart.y2Axis
-                    .tickFormat(d3.format(',.2f'))
+                    .tickFormat(d3.format(',.2f'));
                 chart.xAxis
-                    .tickFormat(function(d) { return d3.time.format('%d %b %y')(new Date(d)) })
+                    .tickFormat(function(d) { return d3.time.format('%d %b %y')(new Date(d)) });
                 chart.x2Axis
-                    .tickFormat(function(d) { return d3.time.format('%d %b %y')(new Date(d)) })
+                    .tickFormat(function(d) { return d3.time.format('%d %b %y')(new Date(d)) });
+                chart.tooltipContent(function(key, y, e, graph) {
+                    var x = d3.time.format('%d %b %Y')(new Date(parseInt(graph.point.x)));
+                    var y = String(graph.point.y);
+                    if(key == 'serie 1'){
+                        var y = 'There is ' +  String(graph.point.y)  + ' calls';
+                    }
+                    tooltip_str = '<center><b>'+key+'</b></center>' + y + ' on ' + x;
+                    return tooltip_str;
+                });
                 d3.select('#lineWithFocusChart svg')
                     .datum(data_lineWithFocusChart)
                     .transition()
@@ -54,6 +65,7 @@ class lineWithFocusChart(NVD3Chart):
     def __init__(self, height=450, width=None, date=False, **kwargs):
         NVD3Chart.__init__(self, **kwargs)
         if date:
+            self.set_date_flag(True)
             self.create_x_axis('xAxis', format='%d %b %Y', date=True)
             self.create_x_axis('x2Axis', format='%d %b %Y', date=True)
             self.set_custom_tooltip_flag(True)
